@@ -1,47 +1,47 @@
 $VAR1 = {
+          'language' => 'en',
           'database' => {
-                          'CurrentHost' => 'localhost',
-                          'CurrentUser' => 'root',
-                          'host' => 'localhost',
                           'user' => 'root',
-                          'CurrentPass' => 'keinz',
-                          'password' => 'keinz',
+                          'CurrentPass' => '',
+                          'CurrentUser' => 'root',
+                          'CurrentHost' => 'localhost',
                           'name' => 'LZE',
-                          'CurrentDb' => 'LZE'
+                          'host' => 'localhost',
+                          'CurrentDb' => 'LZE',
+                          'password' => ''
                         },
-          'mod' => undef,
-          'cgi' => {
-                     'title' => 'MySQL::Admin',
-                     'serverName' => 'myadmin.localhost',
-                     'bin' => '/var/www/cgi-bin',
-                     'alias' => 'perl',
-                     'DocumentRoot' => '/var/www/htdocs',
-                     'cookiePath' => '/',
-                     'expires' => '+1y',
-                     'style' => 'mysql'
-                   },
-          'config' => '/var/www/cgi-bin/config/settings.pl',
+          'version' => '0.8',
+          'translate' => '/var/www/cgi-bin/config/translate.pl',
           'admin' => {
-                       'email' => 'dirk.lze@gmail.com',
+                       'email' => 'your@email.org',
                        'password' => 'testpass'
                      },
-          'session' => '/var/www/cgi-bin/config/session.pl',
-          'scriptAlias' => 'perl',
-          'uploads' => {
-                         'maxlength' => 21000000,
-                         'chmod' => 438,
-                         'path' => '/var/www/htdocs/download'
-                       },
-          'translate' => '/var/www/cgi-bin/config/translate.pl',
-          'apacheconfig' => undef,
           'files' => {
                        'chmod' => '0755',
-                       'owner' => 'www-data',
-                       'group' => 'www-data'
+                       'group' => 'lze',
+                       'owner' => 'lze'
                      },
-          'version' => '0.79',
+          'scriptAlias' => 'perl',
+          'uploads' => {
+                         'chmod' => 438,
+                         'path' => '/var/www/htdocs/download',
+                         'maxlength' => 21000000
+                       },
+          'apacheconfig' => undef,
           'floodtime' => 10,
-          'language' => 'en',
-          'actions' => '/var/www/cgi-bin/config/actions.pl'
+          'config' => '/var/www/cgi-bin/config/settings.pl',
+          'actions' => '/var/www/cgi-bin/config/actions.pl',
+          'cgi' => {
+                     'expires' => '+1y',
+                     'serverName' => 'http://localhost',
+                     'cookiePath' => '/',
+                     'DocumentRoot' => '/var/www/htdocs',
+                     'bin' => '/var/www/cgi-bin',
+                     'title' => 'MySQL::Admin',
+                     'alias' => 'perl',
+                     'style' => 'mysql'
+                   },
+          'mod' => undef,
+          'session' => '/var/www/cgi-bin/config/session.pl'
         };
 $m_hrSettings =$VAR1;
\ No newline at end of file
