@@ -131,6 +131,35 @@ $VAR1 = {
 		    'next' => 'Next',
 		    'change' => 'Ändern',
 		    'Create' => 'Create',
+		    'downLoadFile' => 'Download',
+		    'TINYINT' => "TINYINT -128 TO 127  [0 to 255 if UNSIGNED],Attributes: AUTO_INCREMENT  UNSIGNED, ZEROFILL,SERIAL DEFAULT VALUE Default: NULL [0 if NOT NULL]",
+		    'MEDIUMINT' => '-8,388,608 to 8,388,607 [0 to 16,777,215] Attributes:  AUTO_INCREMENT, UNSIGNED, ZEROFILL,SERIAL DEFAULT VALUE Default: NULL [0 if NOT NULL]',
+		    'INT' => '-/+2.147E+9 [0 to 4.294E+9] AUTO_INCREMENT, UNSIGNED, ZEROFILL,SERIAL DEFAULT VALUE Default: NULL [0 if NOT NULL]',
+		    'BIGINT' => '-/+9.223E+18 [0 to 18.45E+18] Attributes: AUTO_INCREMENT, UNSIGNED, ZEROFILL,SERIAL DEFAULT VALUE Default: NULL [0 if NOT NULL]',
+		    'FLOAT' => 'p=0-24  --> "FLOAT"p=25-53  --> "DOUBLE" Attributes: UNSIGNED, ZEROFILL Default: NULL [0 if NOT NULL]',
+		    'FLOAT' => 'Min=+/-1.175E-38 Max=+/-3.403E+38 Attributes: UNSIGNED, ZEROFILL Default: NULL [0 if NOT NULL]',
+		    'DOUBLE' =>'Min=+/-2.225E-308 Max=+/-1.798E+308 Attributes: UNSIGNED, ZEROFILL Default: NULL [0 if NOT NULL]',
+		    'DECIMAL' => 'Stored as string Max Range = DOUBLE rangeFixed point vs. DOUBLE float Attributes: UNSIGNED, ZEROFILL Default: NULL [0 if NOT NULL]',
+		    'BIT' => 'Binary. Display by [add zero or converting with BIN()]. M=1-64 Attributes: Prior to 5.03TINYINT(1) Synonym Default: NULL [0 if NOT NULL]',
+		    'CHAR' => 'M=0-255 Characters, FIXED.Right padded with spaces. Attributes: BINARY, CHARACTER SET Default: NULL ["" if NOT NULL]',
+		    'VARCHAR' => 'M=0-65,535 CharactersM=0-255 v5.0.3 Attributes: BINARY, CHARACTER SET Default: NULL ["" if NOT NULL]',
+		    'TINYTEXT' => '0-255 Characters Attributes: BINARY, CHARACTER SET Default: NULL ["" if NOT NULL]',
+		    'TEXT' => '0-65,535 Chars Attributes: BINARY, CHARACTER SET Default: NULL ["" if NOT NULL]',
+		    'MEDIUMTEXT' => '0-16,777,215 Chars Attributes: BINARY, CHARACTER SET Default: NULL ["" if NOT NULL]',
+		    'LONGTEXT' => '0-4,294,967,295 Chars Attributes: BINARY, CHARACTER SET Default: NULL ["" if NOT NULL]',
+		    'BINARY' => 'M=0-255 bytes, FIXED. Attributes: Global Only(case sensitive) Default: NULL ["" if NOT NULL]',
+		    'VARBINARY' => '0-65,535 bytesM=0-255 v5.0.3 Attributes: Global Only(case sensitive) Default: NULL ["" if NOT NULL]',
+		    'TINYBLOB' =>'0-255 bytes Attributes: Global Only(case sensitive) Default: NULL ["" if NOT NULL]',
+		    'BLOB' =>'0-65,535 bytes Attributes: Global Only(case sensitive) Default: NULL ["" if NOT NULL]',
+		    'MEDIUMBLOB' => '0-16,777,215 bytes Attributes: Global Only(case sensitive) Default: NULL ["" if NOT NULL]',
+		    'LONGBLOB' => '0-4,294,967,295 bytes Attributes: Global Only(case sensitive) Default: NULL ["" if NOT NULL]',
+		    'ENUM' => 'Column is exactly 1 of 1-65,535 values Attributes: CHARACTER SET Default: NULL [1st value if NOT NULL]',
+		    'SET' => '("A1","A2",...) Column is 0 or more values in list of 1-64 members Attributes: CHARACTER SET Default: NULL ["" if NOT NULL]',
+		    'DATE' => '"1000-01-01" - "9999-12-31" Attributes: Global Only(YYYY-MM-DD) Default: NULL["0000-00-00" if NOT NULL]',
+		    'DATETIME' => '"1000-01-01 00:00:00" -"9999-12-31 23:59:59" Attributes: Global Only(YYYY-MM-DD hh:mm:ss) Default: NULL ["0000-00-00 00:00:00" if NOT NULL]',
+		    'TIME' => '"-838:59:59" - "838:59:59" Attributes: Global Only(hh:mm:ss) Default: NULL["00:00:00" if NOT NULL]',
+		    'TIMESTAMP' => '19700101000000 -2037+ Attributes: Global Only(YYYYMMDDhhmmss) Default: Current Date &amp; Time',
+		    'YEAR' => '1900 - 2155 Attributes: Global Only(YYYY) Default: NULL["0000" if NOT NULL]',
 		    },
           'de' => {
                     'host' => 'Host',
@@ -263,6 +292,36 @@ $VAR1 = {
 		    'next' => 'Weiter',
 		    'change' => 'Ändern',
 		    'Create' => 'Erstellen',
+		    'downLoadFile' => 'Herunterladen',
+		    'TINYINT' => "TINYINT -128 TO 127  [0 to 255 if UNSIGNED],Attributes: AUTO_INCREMENT  UNSIGNED, ZEROFILL,SERIAL DEFAULT VALUE Default: NULL [0 if NOT NULL]",
+		    'SMALLINT' => '-32,768 to 32,767 [0 to 65,535] Attributes: AUTO_INCREMENT, UNSIGNED, ZEROFILL,SERIAL DEFAULT VALUE Default: NULL [0 if NOT NULL]',
+		    'MEDIUMINT' => '-8,388,608 to 8,388,607 [0 to 16,777,215] Attributes:  AUTO_INCREMENT, UNSIGNED, ZEROFILL,SERIAL DEFAULT VALUE Default: NULL [0 if NOT NULL]',
+		    'INT' => '-/+2.147E+9 [0 to 4.294E+9] AUTO_INCREMENT, UNSIGNED, ZEROFILL,SERIAL DEFAULT VALUE Default: NULL [0 if NOT NULL]',
+		    'BIGINT' => '-/+9.223E+18 [0 to 18.45E+18] Attributes: AUTO_INCREMENT, UNSIGNED, ZEROFILL,SERIAL DEFAULT VALUE Default: NULL [0 if NOT NULL]',
+		    'FLOAT' => 'p=0-24  --> "FLOAT"p=25-53  --> "DOUBLE" Attributes: UNSIGNED, ZEROFILL Default: NULL [0 if NOT NULL]',
+		    'FLOAT' => 'Min=+/-1.175E-38 Max=+/-3.403E+38 Attributes: UNSIGNED, ZEROFILL Default: NULL [0 if NOT NULL]',
+		    'DOUBLE' =>'Min=+/-2.225E-308 Max=+/-1.798E+308 Attributes: UNSIGNED, ZEROFILL Default: NULL [0 if NOT NULL]',
+		    'DECIMAL' => 'Stored as string Max Range = DOUBLE rangeFixed point vs. DOUBLE float Attributes: UNSIGNED, ZEROFILL Default: NULL [0 if NOT NULL]',
+		    'BIT' => 'Binary. Display by [add zero or converting with BIN()]. M=1-64 Attributes: Prior to 5.03TINYINT(1) Synonym Default: NULL [0 if NOT NULL]',
+		    'CHAR' => 'M=0-255 Characters, FIXED.Right padded with spaces. Attributes: BINARY, CHARACTER SET Default: NULL ["" if NOT NULL]',
+		    'VARCHAR' => 'M=0-65,535 CharactersM=0-255 v5.0.3 Attributes: BINARY, CHARACTER SET Default: NULL ["" if NOT NULL]',
+		    'TINYTEXT' => '0-255 Characters Attributes: BINARY, CHARACTER SET Default: NULL ["" if NOT NULL]',
+		    'TEXT' => '0-65,535 Chars Attributes: BINARY, CHARACTER SET Default: NULL ["" if NOT NULL]',
+		    'MEDIUMTEXT' => '0-16,777,215 Chars Attributes: BINARY, CHARACTER SET Default: NULL ["" if NOT NULL]',
+		    'LONGTEXT' => '0-4,294,967,295 Chars Attributes: BINARY, CHARACTER SET Default: NULL ["" if NOT NULL]',
+		    'BINARY' => 'M=0-255 bytes, FIXED. Attributes: Global Only(case sensitive) Default: NULL ["" if NOT NULL]',
+		    'VARBINARY' => '0-65,535 bytesM=0-255 v5.0.3 Attributes: Global Only(case sensitive) Default: NULL ["" if NOT NULL]',
+		    'TINYBLOB' =>'0-255 bytes Attributes: Global Only(case sensitive) Default: NULL ["" if NOT NULL]',
+		    'BLOB' =>'0-65,535 bytes Attributes: Global Only(case sensitive) Default: NULL ["" if NOT NULL]',
+		    'MEDIUMBLOB' =>'0-16,777,215 bytes Attributes: Global Only(case sensitive) Default: NULL ["" if NOT NULL]',
+		    'LONGBLOB' => '0-4,294,967,295 bytes Attributes: Global Only(case sensitive) Default: NULL ["" if NOT NULL]',
+		    'ENUM' => 'Column is exactly 1 of 1-65,535 values Attributes: CHARACTER SET Default: NULL [1st value if NOT NULL]',
+		    'SET' => '("A1","A2",...) Column is 0 or more values in list of 1-64 members Attributes: CHARACTER SET Default: NULL ["" if NOT NULL]',
+		    'DATE' => '"1000-01-01" - "9999-12-31" Attributes: Global Only(YYYY-MM-DD) Default: NULL["0000-00-00" if NOT NULL]',
+		    'DATETIME' => '"1000-01-01 00:00:00" -"9999-12-31 23:59:59" Attributes: Global Only(YYYY-MM-DD hh:mm:ss) Default: NULL ["0000-00-00 00:00:00" if NOT NULL]',
+		    'TIME' => '"-838:59:59" - "838:59:59" Attributes: Global Only(hh:mm:ss) Default: NULL["00:00:00" if NOT NULL]',
+		    'TIMESTAMP' => '19700101000000 -2037+ Attributes: Global Only(YYYYMMDDhhmmss) Default: Current Date &amp; Time',
+		    'YEAR' => '1900 - 2155 Attributes: Global Only(YYYY) Default: NULL["0000" if NOT NULL]',
                   }
         };
 $lang =$VAR1;
\ No newline at end of file
