@@ -3,5 +3,5 @@ use strict;
 use utf8;
 use lib qw(lib);
 use MySQL::Admin::GUI;
-ContentHeader("config/settings.pl");
+ContentHeader("cgi-bin//config/settings.pl");
 print Body();
\ No newline at end of file
