@@ -5,11 +5,9 @@ use lib qw(%PATH%/lib);
 use MySQL::Admin qw(:all);
 use MySQL::Admin::Settings;
 use DBI::Library qw(:all);
-loadSettings("%PATH%/config/settings.pl");
-use Template::Quick;
-use HTML::Menu::Pages;
 use DBI::Library::Database qw(:all);
-use MySQL::Admin::GUI;
+loadSettings("%PATH%/config/settings.pl");
+init("%PATH%/config/settings.pl");
 ### 3party
 use URI::Escape;
 # Apache2 mod perl stuff
